@echo off
@rem Set up the working directory and the path to the update.jar file
set LOC=%~dp0
set JAR=%LOC%\update.jar
cd "%LOC%"

@rem Make sure SASHOME is valid
set SASHOME=%~fp1
if not exist "%SASHOME%" (
   echo Invalid SAS Home: "%SASHOME%"
	exit /b -1
)

@rem We have to use the same JRE that the SDW used in the original install, because
@rem it is required to be a 32-bit JRE. The sasdm.ini file contains the path to the
@rem java executable in the "launchercmd" property.
set INI=%SASHOME%\SASDeploymentManager\9.4\sasdm.ini
if not exist "%INI%" (
   echo Missing file: "%INI%"
	exit /b -1
)

@rem Parse the value of launchercmd from the sasdm.ini file and set JAVA to that value,
@rem which is the full path to the java executable.
for /F "tokens=1,2 delims== usebackq" %%i in (`type "%INI%"`) do if "%%i"=="launchercmd" (set JAVA=%%j)

@rem On native 32-bit Windows systems, we have to use the installed private JRE
if "%JAVA%" equ "<PRIVATEJREHOME>" (
   set JAVA=%SASHOME%\SASPrivateJavaRuntimeEnvironment\9.4\jre\bin\java.exe
)

@rem Make sure the java executable exists.
if not exist "%JAVA%" (
   echo Cannot run java, "%JAVA%" was not found.
   exit /b -1
)

@rem Prevent this from installing on anything prior to 9.4m5. This looks really stupid,
@rem but because we cannot rely on "base" being present (as is the case for a client-only
@rem install), we have to use "instqualtool" as the product to check. Its version number
@rem is 9.49516 and that is supposedly never going to change. For 9.4m5, instqualtool
@rem was at maintenance levels 2 and 3. So we check the maintenance level of instqualtool and
@rem if it is not 2 or 3, the installation is not at 9.4m5. Unfortunately this does
@rem not allow us to inform the user what their maintenance level actually is. All we can
@rem do is tell them they are not at 9.4m5. Note that the return value from the
@rem deployment registry query can be "null" so we have to handle that as well. What that
@rem means is that the version number of instqualtool is not 9.49516.

set DPR=%SASHOME%\deploymntreg\sas.tools.deploymntreg.jar
"%JAVA%" -jar "%DPR%" --view 9.4 getMaintLevel "instqualtool" "9.49516" > ml.txt
set /p ML=<ml.txt
del ml.txt
if "%ML%" equ "null" (
   goto :bad
)
if "%ML%" equ "2" (
   goto :good
)
if "%ML%" equ "3" (
   goto :good
)

:bad
   echo This update can only be installed on a deployment that is SAS 9.4M5.
   exit /b -1

:good

@rem Now invoke the Install Tool wrapper to run the install.
"%JAVA%" -jar "%JAR%" "%SASHOME%"

