#!/bin/sh
#
# Set up the working directory and the path to the update.jar file
LOC=`dirname "$0"`
JAR=$LOC/update.jar
cd "$LOC"

# Make sure SASHOME is valid
SASHOME=$1
if [ ! -d "$SASHOME" ] ; then
   echo "invalid SAS Home"
	exit 1
fi

# Make sure the private JRE is present and valid. Here we have to do some
# special checks for Sun and HP platforms to set the right options to pass
# to the JRE.
JAVA=$SASHOME/SASPrivateJavaRuntimeEnvironment/9.4/jre/bin/java
if [ ! -f "$JAVA" ] ; then
   echo "jre not found"
	exit 1
fi
JREOPT=""
OS=`uname`
if [ "$OS" = "SunOS" ] ; then
   JREOPT="-d64"
fi
if [ "$OS" = "HP-UX" ] ; then
   MOD=`model`
   if [ "`set -f ; echo $MOD | sed -n '/ia64/ {p;}'`" ] ; then
      JREOPT="-d64"
   fi
fi

# Prevent this from installing on anything prior to 9.4m5. This looks really stupid,
# but because we cannot rely on "base" being present (as is the case for a client-only
# install), we have to use "instqualtool" as the product to check. Its version number
# is 9.49516 and that is supposedly never going to change. For 9.4m5, instqualtool
# was at maintenance levels 2 and 3. So we check the maintenance level of instqualtool and
# if it is not 2 or 3, the installation is not at 9.4m5. Unfortunately this does
# not allow us to inform the user what their maintenance level actually is. All we can
# do is tell them they are not at 9.4m5. Note that the return value from the
# deployment registry query can be "null" so we have to handle that as well. What that
# means is that the version number of instqualtool is not 9.49516.

DPR=$SASHOME/deploymntreg/sas.tools.deploymntreg.jar
ML=`"$JAVA" -jar "$DPR" --view 9.4 getMaintLevel "instqualtool" "9.49516"`
if [ "$ML" = "null" ] ; then
   echo This update can only be installed on a deployment that is SAS 9.4M5.
   exit 1
fi
if test ! $ML -eq 2 && test ! $ML -eq 3 ; then
   echo This update can only be installed on a deployment that is SAS 9.4M5.
   exit 1
fi

# Invoke the Install Tool wrapper to run the install.
"$JAVA" $JREOPT -jar "$JAR" "$SASHOME"
